@@ -7,14 +7,15 @@
 #pragma once
 
 #include <QObject>
-
-class QQuickItem;
+#include <QQuickItem>
+#include <qqmlintegration.h>
 
 class Blur : public QObject
 {
     Q_OBJECT
+    QML_ELEMENT
 
 public:
-    Blur(QObject *parent = 0);
+    Blur(QObject *parent = nullptr);
     Q_INVOKABLE void setBlur(QQuickItem *item, bool blur);
 };
